@@ -17,8 +17,6 @@ class QTimer;
 
 class KateCompletionTree final : public QTreeView
 {
-    Q_OBJECT
-
 public:
     explicit KateCompletionTree(KateCompletionWidget *parent);
 
@@ -44,17 +42,13 @@ public:
 
     void setScrollingEnabled(bool);
 
-private Q_SLOTS:
+private:
     void resizeColumnsSlot();
 
 protected:
     void currentChanged(const QModelIndex &current, const QModelIndex &previous) override; /// Not available as a signal in this way
     void scrollContentsBy(int dx, int dy) override;
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     void initViewItemOption(QStyleOptionViewItem *option) const override;
-#else
-    QStyleOptionViewItem viewOptions() const override;
-#endif
 
 private:
     bool m_scrollingEnabled;
