@@ -1024,7 +1024,6 @@ public:
         WordCompletion,
         WordCompletionMinimalWordLength,
         WordCompletionRemoveTail,
-        ShowFocusFrame,
         ShowDocWithCompletion,
         MultiCursorModifier,
         ShowFoldingOnHoverOnly,
@@ -1120,11 +1119,6 @@ public:
         return value(ShowScrollbars).toInt();
     }
 
-    bool showFocusFrame() const
-    {
-        return value(ShowFocusFrame).toBool();
-    }
-
     bool showDocWithCompletion() const
     {
         return value(ShowDocWithCompletion).toBool();
